@@ -44,7 +44,7 @@ corpus_config: CorpusConfig = CorpusConfig.load(os.path.join(__paths__.resources
 # ### <span style='color: green'>PREPARE</span> Load Topic Model <span style='float: right; color: red'>MANDATORY</span>
 
 # %%
-load_gui: ntm.LoadGUI = ntm.LoadGUI(corpus_folder=corpus_folder, state=current_state()).setup()
+load_gui: ntm.LoadGUI = ntm.LoadGUI(data_folder=corpus_folder, state=current_state()).setup()
 display(load_gui.layout())
 
 # %% [markdown]
@@ -53,9 +53,8 @@ display(load_gui.layout())
 # Displays topics in which given token is among toplist of dominant words.
 
 # %%
-ntm.find_topic_documents_gui(
-    current_state().inferred_topics.document_topic_weights, current_state().inferred_topics.topic_token_overview
-)
+fd_ui = ntm.FindTopicDocumentsGUI(current_state()).setup()
+display(fd_ui.layout())
 
 # %% [markdown]
 # ### <span style='color: green;'>BROWSE</span> Browse Topic Documents<span style='color: red; float: right'>TRY IT</span>
@@ -63,7 +62,8 @@ ntm.find_topic_documents_gui(
 # Displays documents in which a topic occurs above a given threshold.
 
 # %%
-ntm.display_topic_documents_gui(current_state())
+td_ui = ntm.BrowseTopicDocumentsGUI(current_state()).setup()
+display(td_ui.layout())
 
 # %% [markdown]
 # ### <span style='color: green;'>VISUALIZE</span> Display Topic's Word Distribution as a Wordcloud<span style='color: red; float: right'> TRY IT</span>
